@@ -110,7 +110,7 @@ def limit_scan_deprecated(**kwargs):
 @click.command(name='limit_scan')
 @click.option('-i', '--input_path', 'input_path', required=True, 
               help='Input directory/path containing the workspace file(s) to process.')
-@click.option('--file_expr', default=r"\w+", show_default=True,
+@click.option('--file_expr', default=r"[\w-]+", show_default=True,
               help='\b\n File name expression describing the external parameterisation.'
                    '\b\n Example: "<mass[F]>_kl_<klambda[P]>"'
                    '\b\n Regular expression is supported'
