@@ -5,6 +5,7 @@ from quickstats.components import AnalysisObject
 from quickstats.utils.common_utils import parse_config
 
 class AsimovType(enum.Enum):
+    Temp                   = -999
     S_NP_Nom               = -2
     B_NP_Nom               = -1
     B_NP_Fit               = 0
@@ -17,6 +18,7 @@ class AsimovType(enum.Enum):
 class AsimovGenerator(AnalysisObject):
 
     ASIMOV_SETTINGS = {
+        AsimovType.Temp: None,
         AsimovType.S_NP_Nom: {
             "asimov_name": "asimovData_1_NP_Nominal",
             "asimov_snapshot": "asimovData_1_NP_Nominal",
@@ -125,6 +127,8 @@ class AsimovGenerator(AnalysisObject):
             if isinstance(asimov_type, int):
                 asimov_type = AsimovType(asimov_type)
             kwargs = self.ASIMOV_SETTINGS[asimov_type]
+            if kwargs is None:
+                continue
             kwargs['poi_name'] = poi_name
             for key in ['poi_val', 'poi_profile']:
                 if kwargs[key] is not None:
