@@ -10,6 +10,7 @@ from quickstats.components import AnalysisObject
 from quickstats.utils.root_utils import load_macro
 from quickstats.utils import common_utils
 from quickstats.utils.io import Verbosity
+from quickstats.maths.numerics import pretty_value
 
 import ROOT
 
@@ -129,7 +130,9 @@ class AsymptoticCLs(AnalysisObject):
         if ( val < 0 ) and (self.poi.getMin() > val):
             self.poi.setMin(2*val)
         self.poi.setVal(val)
-        
+    
+    """
+    # superceded by AnalysisObject
     def save_snapshot(self, name:str, target:str="nuis"):
         if target == "nuis":
             self.ws.saveSnapshot(name, self.nuis)
@@ -142,13 +145,14 @@ class AsymptoticCLs(AnalysisObject):
             raise RuntimeError('snapshot "{}" does not exist'.format(name))
         self.stdout.debug('INFO: Loaded snapshot "{}"'.format(name))
         self.ws.loadSnapshot(name)
+    """
             
     def save_nll_snapshot(self, nll, mu):
-        name = self.nll_snapshot_name.format(nll_name=nll.GetName(), mu=mu)
-        self.ws.saveSnapshot(name, self.nuis)
+        name = self.nll_snapshot_name.format(nll_name=nll.GetName(), mu=pretty_value(mu))
+        self.save_snapshot(name, self.nuis)
         
     def load_nll_snapshot(self, nll, mu):
-        name = self.nll_snapshot_name.format(nll_name=nll.GetName(), mu=mu)
+        name = self.nll_snapshot_name.format(nll_name=nll.GetName(), mu=pretty_value(mu))
         self.load_snapshot(name) 
     
     def load_conditional_snapshot(self, mu:float, target:str="nuis"):
@@ -157,9 +161,9 @@ class AsymptoticCLs(AnalysisObject):
     
     def get_conditional_snapsot_name(self, mu:float, target:str="nuis"):
         if target == "nuis":
-            name = self.model._DEFAULT_NAMES_['conditional_nuis'].format(mu=mu)
+            name = self.model._DEFAULT_NAMES_['conditional_nuis'].format(mu=pretty_value(mu))
         elif target == "globs":
-            name = self.model._DEFAULT_NAMES_['conditional_globs'].format(mu=mu)
+            name = self.model._DEFAULT_NAMES_['conditional_globs'].format(mu=pretty_value(mu))
         else:
             raise ValueError('unknown conditional snapshot target "{}"'.format(target))
         return name
@@ -183,7 +187,7 @@ class AsymptoticCLs(AnalysisObject):
         return nll_val
     
     def create_nll(self, dataset:"ROOT.RooDataSet"):
-        return self.pdf.createNLL(dataset, *self.minimizer.nll_command_list)
+        return self.minimizer._create_nll(dataset=dataset)
         
     def get_qmu(self, nll:"ROOT.RooNLLVar", mu:float):
         nll_muhat = self.nll_maps[nll].get('nll_mu_hat', None)
@@ -485,8 +489,8 @@ class AsymptoticCLs(AnalysisObject):
         self.nll_maps[obs_nll] = {"dataset": self.data, "snapshot": self.nom_glob_name}
         self.dataset_maps[self.data] = obs_nll
         
-        self.save_snapshot(self.nom_glob_name, target="globs")
-        self.save_snapshot(self.nom_nuis_name, target="nuis")
+        self.save_snapshot(self.nom_glob_name, variables="globs")
+        self.save_snapshot(self.nom_nuis_name, variables="nuis")
         
         asimov_data_0 = self.model.generate_asimov(self.poi.GetName(), poi_val=0,
                                                    poi_profile=0, 
