@@ -264,7 +264,7 @@ class ExtendedModel(AbstractObject):
         # Load global observables
         global_observables = model_config.GetGlobalObservables()
         if not global_observables:
-            self.stdout.warning("WARNING: No nuisance parameters found in the workspace. "
+            self.stdout.warning("WARNING: No global observables found in the workspace. "
                                 "An empty set will be loaded by default.")            
             global_observables = ROOT.RooArgSet()
         else:
@@ -447,7 +447,9 @@ class ExtendedModel(AbstractObject):
             # case both parameter name and value is given
             elif len(expr) == 2:
                 param_name = expr[0]
-                param_values = [float(v) for v in expr[1].split("_")]
+                param_values = [float(v) if v else None for v in expr[1].split("_")]
+                if len(param_values) == 1:
+                    param_values = param_values[0]
                 param_dict[param_name] = param_values
             else:
                 raise ValueError('invalid parameter expression: {}'.format(param))
@@ -854,6 +856,9 @@ class ExtendedModel(AbstractObject):
             raise ValueError('the argument "obs_and_weight" must be of RooArgSet type')
         return obs_and_weight, weight_var
     
+    def import_object(self, obj):
+        getattr(self.workspace, "import")(obj)
+        
     @staticmethod
     def get_object_map(object_dict:Dict, object_name:str):
         ExtendedModel.load_RooFitObjects()
@@ -1077,7 +1082,7 @@ class ExtendedModel(AbstractObject):
             if isinstance(nll_options, dict):
                 minimizer.configure_nll(all_nuis, all_globs, **nll_options)
             elif isinstance(nll_options, list):
-                minimizer.nll_command_list = nll_options
+                minimizer.set_nll_commands(nll_options)
             else:
                 raise ValueError(f"unsupported nll options format")
             if poi_profile is not None:
@@ -1150,8 +1155,17 @@ class ExtendedModel(AbstractObject):
         
         return asimov_data
     
-    def generate_toys(self, n_toys:int=1, seed:int=0, binned:bool=True, 
+    def generate_toys(self, n_toys:int=1, seed:Union[int, List[int]]=0, 
+                      binned:bool=True, randomize_globs:bool=True,
                       do_import:bool=True, name="toyData_{index}_seed_{seed}"):
+        if n_toys > 1:
+            if seed == 0:
+                seeds = [0] * n_toys
+            elif (not isinstance(seed, (list, np.ndarray, range))) or (len(seed) != n_toys):
+                raise ValueError("seed must be a list of size n_toys if seed != 0")
+            else:
+                seeds = seed
+                
         ws = self.workspace
         # take snapshot of initial states of all variables
         self.workspace.saveSnapshot("tmp", self.workspace.allVars())
@@ -1171,11 +1185,14 @@ class ExtendedModel(AbstractObject):
             args.append(ROOT.RooFit.GenBinned("GenerateToys::Binned"))
         
         for i in range(n_toys):
-            self.randomize_globs(self.pdf, self.global_observables, seed)
+            if randomize_globs:
+                self.randomize_globs(self.pdf, self.global_observables, seeds[i])
             toy = self.pdf.generate(*args)
-            toy_name = name.format(seed=seed, index=i)
+            toy_name = name.format(seed=seeds[i], index=i)
             toy.SetName(toy_name)
             if do_import:
+                if ws.data(toy_name):
+                    raise RuntimeError(f"attempt to overwrite existing dataset `{toy_name}`")
                 getattr(ws, "import")(toy)
                 self.stdout.info(f'INFO: Generated toy dataset "{toy_name}"')
             toys.append(toy)
