@@ -40,7 +40,7 @@ class ParameterisedAsymptoticCLs(ParameterisedRunner):
     
     @semistaticmethod
     def _prerun_instance(self, filename:str, parameters:Optional[Dict[str, Any]]=None, **kwargs):
-        if parameters is not None:
+        if parameters:
             param_str = "("+ParamParser.val_encode_parameters(parameters)+")"
         else:
             param_str = ""
@@ -108,6 +108,8 @@ class ParameterisedAsymptoticCLs(ParameterisedRunner):
             'filenames': param_data['filenames'],
             'parameters': param_data['parameters']
         }
+        if not kwarg_set:
+            raise RuntimeError("no parameter point to scan for")
         return kwarg_set, auxiliary_args
     
     def postprocess(self, raw_result, auxiliary_args:Optional[Dict]=None):
@@ -117,8 +119,11 @@ class ParameterisedAsymptoticCLs(ParameterisedRunner):
         final_result = []
         for filename, params, limit in zip(filenames, parameters, raw_result):
             if len(limit) == 0:
-                param_str = ParamParser.val_encode_parameters(params)
-                raise RuntimeError(f'Job failed for the input "{filename}" ({param_str}). '
+                if params:
+                    param_str = "("+ParamParser.val_encode_parameters(params)+")"
+                else:
+                    param_str = ""                
+                raise RuntimeError(f'Job failed for the input "{filename}" {param_str}. '
                                    'Please check the log file for more details.')
             final_result.append({**params, **limit})
         final_result = pd.DataFrame(final_result).to_dict('list')
