@@ -140,6 +140,8 @@ class ParameterisedLikelihood(ParameterisedRunner):
         auxiliary_args = {
             'points': poi_values
         }
+        if not kwarg_set:
+            raise RuntimeError("no parameter point to scan for")        
         return kwarg_set, auxiliary_args
     
     def postprocess(self, raw_result, auxiliary_args:Optional[Dict]=None):
