@@ -37,7 +37,7 @@ signature_parser = {
 
 class ParamParser:
     
-    DEFAULT_FORMAT_STR = r"\w+"
+    DEFAULT_FORMAT_STR = r"[\w-]+"
     
     DEFAULT_FILE_EXT = ".root"
     
