@@ -515,7 +515,7 @@ class NPRankingPlot:
         centralize_axis(ax2, 'x')
         if shade:
             draw_hatches(ax2, n, height=height, **style['shade'])
-        NPRankingPlot.plot_pulls(ax1, data, height=height, **style)
+        NPRankingPlot.plot_pulls(ax1, data, show_sigma=show_sigma, height=height, **style)
         if sigma_bands:
             draw_sigma_bands(ax1, n, height=height)
         if sigma_lines:
@@ -531,8 +531,12 @@ class NPRankingPlot:
                                   ranking_label=ranking_label, energy=energy, lumi=lumi, status=status,
                                   r_start=r_start, r_end=r_start + n - 1, **style)
         x_legend = style['legend']['x']
-        NPRankingPlot.draw_legend(ax1, display_poi, x=x_legend, y=-1.2*height, show_prefit=show_prefit,
-                                  show_postfit=show_postfit, correlation=correlation, **style)
+        NPRankingPlot.draw_legend(ax1, display_poi, x=x_legend, y=-1.2*height, show_sigma=show_sigma,
+                                  show_prefit=show_prefit, show_postfit=show_postfit, correlation=correlation, **style)
+        # hide impact axis if no impacts are plotted
+        if (not show_prefit) and (not show_postfit):
+            ax2.set_xlabel("")
+            ax2.get_xaxis().set_visible(False)
         return fig
     
     def plot(self, show_sigma:bool=True, show_prefit:bool=True, show_postfit:bool=True, sigma_bands:bool=False,
